@@ -1,7 +1,6 @@
 package Slay::Makefile;
 
 use warnings;
-no warnings qw(void);
 use strict;
 
 =head1 NAME
@@ -10,9 +9,9 @@ Slay::Makefile - Wrapper to Slay::Maker that reads the rules from a file
 
 =cut
 
-our $VERSION = '0.13_51';
+our $VERSION = '0.01';
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 C<Slay::Maker> is a make engine that uses perl declaration syntax for
 rules, including regular expressions for targets and anonymous subs
@@ -60,10 +59,10 @@ or a <perl-block> which returns an array of dependencies (or a
 combination). The dependency string can contain C<$1>, C<$2>, ..., or
 C<%>, which is synonymous with C<$1> and C<${TARGET}>, which gets the
 target name.  They can also use any scalar global variables previously
-defined in a <perl-block>.  A dependency <perl-block> is called with
-the values C<($make, $target, $matches)>, where C<$make> is a
-C<Slay::Maker> object, C<$target> is the target name, and C<$matches> is
-a reference to an array containing the captured values from that
+defined in a <perl-block>.  A dependency <perl-block> receives an
+array C<@_> with the values ($make, $target, $matches), where $make is
+a Slay::Maker object, $target is the target name, and $matches is a
+reference to an array containing the captured values from that
 target's Regexp (if any).
 
 The colon separating a <perl-block> for <dependencies> must be on the
@@ -80,35 +79,25 @@ C<$2>, ..., for the matches, C<$DEP0>, C<$DEP1>, ..., for the
 dependencies, and C<$TARGET>, which represents the target being built.
 For make enthusiasts, C<$*> can be used for C<$1>.  A string action
 can also use any scalar global variables previously defined in a
-<perl-block>.  An action <perl-block> is called with the values
-C<($make, $target, $deps, $matches)>, where C<$make> is a C<Slay::Maker>
-object, C<$target> is the target name, C<$deps> is a reference to the
-array of dependencies and $matches is a reference to an array
-containing the captured values from that target's Regexp (if any).
+<perl-block>.
 
 An include line includes the content of a file with <filename> as a
-SlayMakefile file.  If there is no such file, C<Slay::Makefile> tries
-to build it using rules that have already been presented.  If there is
-no such rule, C<Slay::Makefile> exits with an error unless there was a
-C<-> before the "include".
+SlayMakefile file.  If there is no such file, Slay::Makefile will try to
+build it using rules that have already been presented.  If there is no
+such rule, Slay::Makefile exits with an error unless there was a C<->
+before the "include".
 
 The equivalent of make's defines are handled by setting perl global
 variables.  Each main <perl-block> is executed in the order it appears
 in the file, but any <perl-block> that is part of a dependency or
 action is evaluated lazily, so that all the global variables will have
-been set.  A main <perl-block> is called with the value
-C<($makefile)>, where C<$makefile> is the C<Slay::Makefile> object,
-so that such code can, for example, recursively call the parse method.
+been set.
 
 Comments begin with a C<#> and extend to the end of line.
 
 Continuation lines can be specified by putting a backslash at the end
 of the previous line, provided however, that continuation lines are
 unnecessary (automatic) within a perl block or perl anonymous array.
-Although continuation lines in a perl dependency or action must begin
-with at least one space so a that the parser does not think a new rule
-is beginning, the minimum indentation is removed prior to evaluation
-so that HEREIS strings can be used.
 
 =head1 METHODS
 
@@ -117,15 +106,11 @@ so that HEREIS strings can be used.
 =cut
 
 use Carp;
-use Slay::Maker 0.04;
+use Slay::Maker;
 
-=item C<new([$options])>
+=item C<new>
 
-Class method.  Creates a new C<Slay::Makefile> object using the
-optional C<$options> argument.  It also process the following options
-out of C<$options>:
-
-  strict:      If 0, do not enforce strict checking on perl blocks
+Class method.  Creates a new C<Slay::Makefile> object.
 
 =cut
 
@@ -135,8 +120,7 @@ sub new {
     my $self = bless {}, $class;
     $options = {} unless $options;
 
-    $self->{maker}   = new Slay::Maker({options => $options});
-    $self->{options} = $options;
+    $self->{maker} = new Slay::Maker($options);
 
     return $self;
 }
@@ -224,7 +208,6 @@ sub parse_string : method {
 	    elsif ($stmt =~ /^\s*(-?)\s*include\s+(?!:)(.*)/) {
 		# include directive
 		my ($opt, $incfile) = ($1, $2);
-		$incfile = eval qq(package Slay::Makefile::Eval; "$incfile");
 		if (! -f $incfile) {
 		    # Check if we can build it with rules we already have
 		    eval { $self->{maker}->make($incfile) } ;
@@ -358,7 +341,6 @@ sub parse_string : method {
 			    }
 			    else {
 				# It's a command
-				$act2 = _expand($act2, $brackets, qw([ ]));
 				chomp ($act2 =
 				       _substitute(_expand($act2, $braces)));
 				$act2 =~ s/^\s*\#.*//;
@@ -408,8 +390,7 @@ sub parse_string : method {
 			    }
 			    # Remove the enclosing {}
 			    $perl =~ s/\A \{ (.*) \} \z/$1/xs;
-			    $self->_eval("\@_ = \$self; $perl", $filename,
-					 $stmt_line);
+			    $self->_eval($perl, $filename, $stmt_line);
 			    $stmt_line += $perl =~ tr/\n//;
 			}
 			else  {
@@ -426,7 +407,6 @@ sub parse_string : method {
 	    $stmt_line = $lineno+$l+1;
 	}
     }
-    $self->_croak("Unmatched \{", $filename, $stmt_line) if $in_braces;
     return $self->{errors};
 }
 
@@ -480,17 +460,8 @@ sub _collapse {
 sub _eval : method {
     my ($self, $perl, $filename, $stmt_line) = @_;
 
-    my $ld = defined $filename ? qq(\#line $stmt_line "$filename"\n) : '';
-    my $strict = defined $self->{options}{strict} &&
-	$self->{options}{strict} == 0 ? 'no strict;' : '';
-    # Remove minimum indentation of perl block so that HEREIS strings
-    # can be used as part of dependencies or actions
-    $perl =~ s/^(\t+)/' ' x (8*length($1))/gem;
-    my @indents = $perl =~ m/^([ ]+)/gm;
-    my $min_indent = @indents ? $indents[0] : '';
-    grep do {$min_indent = $_ if length $_ < length $min_indent}, @indents;
-    $perl =~ s/^$min_indent//gm if $min_indent;
-    my @val = eval "${ld}package Slay::Makefile::Eval; $strict $perl";
+    my $ld = qq(\#line $stmt_line "$filename"\n);
+    my @val = eval "${ld}package Slay::Makefile::Eval; no strict; $perl";
     chomp $@;
     $self->_croak($@, $filename, $stmt_line) if $@;
     return @val;
