@@ -2,9 +2,6 @@
 use strict;
 use warnings;
 
-use File::Path qw(rmtree);
-use File::Copy::Recursive qw(dircopy);
-
 use Test::More;
 
 use FindBin;
@@ -25,8 +22,8 @@ sub do_tests {
     die "Error: No init directory for this test\n" unless -d "$myname.init";
 
     # First create the subdirectory for doing testing
-    rmtree "$myname.dir" if -d "$myname.dir";
-    dircopy "$myname.init", "$myname.dir";
+    system "rm -rf $myname.dir" if -d "$myname.dir";
+    system "cp -r $myname.init $myname.dir";
 
     chdir "$myname.dir";
 
@@ -36,20 +33,20 @@ sub do_tests {
 	plan(skip_all => "$error") if $?;
     }
 
-    my %options;
-    my $sm = Slay::Makefile->new();
+    my $sm = Slay::Makefile->new;
     $sm->parse("../Common.smak");
     $sm->maker->check_targets('test');
 
     # Get list of targets
-    my ($rule, $deps, $matches) = $sm->maker->get_rule_info('test');
-    my @tests = @ARGV ? @ARGV : defined $rule && $deps ? @$deps : () ;
+    #    N.B.: there should be a way to do this without looking
+    #    under the skirts of Slay::Maker.
+    my ($target, $rule, $deps, $matches) = @{$sm->maker->{QUEUE}} ?
+	@{$sm->maker->{QUEUE}[-1]} : ();
+    my @tests = @ARGV ? @ARGV : defined $target && $deps ? @$deps : () ;
     plan tests => 0+@tests;
     foreach my $test (@tests) {
 	$sm->make($test);
 	my $ok = -r $test ? `cat $test` : "Failed to build $test";
-	local $TODO;
-	$TODO = "Known test failure (https://github.com/Perl/perl5/issues/20864)" if $] >= 5.037009 && $test eq 'bad_opt_e.ok'; # XXX review + maybe apply https://github.com/eserte/Slay-Makefile/pull/6
 	is ($ok, '', $test);
     }
 }
